@@ -21,15 +21,12 @@
 #include "Exception.hpp"
 #include "Array.hpp"
 #include "Malloc.hpp"
+#include "RPC.hpp"
 #include <math.h>
 
-//FIXME
-#ifndef WIN32
-//#include "config.h"
 #ifdef USE_MPI
 #include "MPIWrap.hpp"
 #endif
-#endif
 
 void LoadGUICoreFunctions(Context* context) {
   context->addGfxSpecialFunction("helpwin",HelpWinFunction,0,0,NULL);
@@ -38,6 +35,19 @@ void LoadGUICoreFunctions(Context* context) {
 }
 
 void LoadCoreFunctions(Context* context) {
+  context->addFunction("tcpserver",TCPServerFunction,1,1,"port",NULL);
+  context->addFunction("tcpaccept",TCPAcceptFunction,2,1,"handle","timeout",NULL);
+  context->addFunction("tcpconnect",TCPConnectFunction,3,1,"remoteip","port","timeout",NULL);
+  context->addFunction("tcpsend",TCPSendFunction,3,1,"handle","data","timeout",NULL);
+  context->addFunction("tcprecv",TCPRecvFunction,2,1,"handle","timeout",NULL);
+  context->addFunction("tcpclose",TCPCloseFunction,1,0,"handle",NULL);
+  context->addFunction("tcpserverclose",TCPServerCloseFunction,1,0,"handle",NULL);
+  context->addFunction("tcpstate",TCPStateFunction,1,1,"handle",NULL);
+  context->addFunction("true",TrueFunction,0,1,NULL);
+  context->addFunction("false",FalseFunction,0,1,NULL);
+  context->addFunction("regexp",RegExpFunction,-1,6,NULL);
+  context->addFunction("regexprepdriver",RegExpRepDriverFunction,-1,1,NULL);
+  context->addFunction("regexpi",RegExpIFunction,-1,6,NULL);
   context->addFunction("cos",CosFunction,1,1,"x",NULL);
   context->addFunction("acos",ArccosFunction,1,1,"x",NULL);
   context->addFunction("csc",CscFunction,1,1,"x",NULL);
@@ -56,6 +66,7 @@ void LoadCoreFunctions(Context* context) {
   context->addFunction("max",MaxFunction,3,2,"x","z","n",NULL);
   context->addFunction("sum",SumFunction,2,1,"x","d",NULL);
   context->addFunction("cumsum",CumsumFunction,2,1,"x","d",NULL);
+  context->addFunction("cumprod",CumprodFunction,2,1,"x","d",NULL);
   context->addFunction("mean",MeanFunction,2,1,"x","d",NULL);
   context->addFunction("var",VarFunction,2,1,"x","d",NULL);
   context->addFunction("prod",ProdFunction,2,1,"x","d",NULL);
@@ -93,7 +104,7 @@ void LoadCoreFunctions(Context* context) {
   context->addFunction("qr",QRDFunction,2,-1,"x","n",NULL);
   context->addFunction("int2bin",Int2BinFunction,2,1,"x","n",NULL);
   context->addFunction("bin2int",Bin2IntFunction,2,1,"x","flags",NULL);
-  context->addFunction("eig",EigFunction,2,2,"A","balanceflag",NULL);
+  context->addSpecialFunction("eig",EigFunction,2,2,"A","balanceflag",NULL);
   context->addFunction("eigs",EigsFunction,-1,-1,"A",NULL);
   context->addFunction("isempty",IsEmptyFunction,1,1,"x",NULL);
   context->addFunction("zeros",ZerosFunction,-1,1,NULL);
@@ -105,6 +116,7 @@ void LoadCoreFunctions(Context* context) {
   context->addFunction("error",ErrorFunction,1,0,"x",NULL);
   context->addSpecialFunction("warning",WarningFunction,1,0,"x",NULL);
   context->addSpecialFunction("lasterr",LasterrFunction,1,1,"x",NULL);
+  context->addSpecialFunction("errorcount",ErrorCountFunction,0,1,NULL);
   context->addFunction("typeof",TypeOfFunction,1,1,"x",NULL);
   context->addFunction("strcomp",StrCmpFunction,2,1,"x","y",NULL);
   context->addFunction("struct",StructFunction,-1,1,NULL);
@@ -125,7 +137,13 @@ void LoadCoreFunctions(Context* context) {
   context->addSpecialFunction("setpath",SetPathFunction,1,0,"pathlist",NULL);
   context->addSpecialFunction("getpath",GetPathFunction,0,1,NULL);
   context->addSpecialFunction("ls",ListFilesFunction,-1,0,NULL);
-  context->addSpecialFunction("dir",ListFilesFunction,-1,0,NULL);
+  context->addSpecialFunction("dir",DirFunction,1,1,"dirname",NULL);
+  context->addSpecialFunction("diary",DiaryFunction,1,1,"flag",NULL);
+  context->addFunction("rmdir",RMDirFunction,2,0,"dirname","flag",NULL);
+  context->addFunction("delete",DeleteFunction,1,0,"filename",NULL);
+  context->addFunction("copyfile",CopyFileFunction,2,0,"source","dest",NULL);
+  context->addFunction("mkdir_core",MKDirCoreFunction,1,1,"dirname",NULL);
+  context->addFunction("fileparts",FilePartsFunction,1,4,"filename",NULL);
   context->addFunction("system",SystemFunction,1,1,"command",NULL);
   context->addSpecialFunction("feval",FevalFunction,-1,-1,NULL);
   context->addSpecialFunction("builtin",BuiltinFunction,-1,-1,NULL);
@@ -135,6 +153,7 @@ void LoadCoreFunctions(Context* context) {
   context->addSpecialFunction("assignin",AssignInFunction,3,0,"workspace","name","value",NULL);
   context->addSpecialFunction("source",SourceFunction,1,0,"filename",NULL);
   context->addSpecialFunction("who",WhoFunction,-1,0,NULL);
+  context->addSpecialFunction("simkeys",SimKeysFunction,1,1,"text",NULL);
   context->addSpecialFunction("exist",ExistFunction,2,1,"name","type",NULL);
   context->addSpecialFunction("isset",IsSetFunction,1,1,"name",NULL);
   context->addSpecialFunction("which",WhichFunction,1,1,"fname",NULL);
@@ -148,6 +167,7 @@ void LoadCoreFunctions(Context* context) {
   context->addFunction("fgetline",FgetlineFunction,1,1,"handle",NULL);
   context->addFunction("feof",FeofFunction,1,1,"handle",NULL);
   context->addSpecialFunction("printf",PrintfFunction,-1,0,NULL);
+  context->addSpecialFunction("verstring",VerStringFunction,0,1,NULL);
   context->addFunction("sprintf",SprintfFunction,-1,1,NULL);
   context->addFunction("fprintf",FprintfFunction,-1,0,NULL);
   context->addFunction("fscanf",FscanfFunction,2,-1,"handle","format",NULL);
@@ -168,7 +188,7 @@ void LoadCoreFunctions(Context* context) {
   context->addFunction("randchi",RandChiFunction,1,1,"dof",NULL);
   context->addFunction("randexp",RandExpFunction,1,1,"means",NULL);
   context->addFunction("randp",RandPoissonFunction,1,1,"means",NULL);
-  context->addFunction("find",FindFunction,3,-1,"x","k","flags",NULL);
+  context->addSpecialFunction("find",FindFunction,3,-1,"x","k","flags",NULL);
   context->addFunction("conj",ConjFunction,1,1,"x",NULL);
   context->addFunction("real",RealFunction,1,1,"x",NULL);
   context->addFunction("imag",ImagFunction,1,1,"x",NULL);
@@ -178,10 +198,10 @@ void LoadCoreFunctions(Context* context) {
   context->addSpecialFunction("clear",ClearFunction,-1,0,NULL);
   context->addSpecialFunction("setprintlimit",SetPrintLimitFunction,1,0,"n",NULL);
   context->addSpecialFunction("getprintlimit",GetPrintLimitFunction,0,1,NULL);
-  context->addFunction("sleep",SleepFunction,1,0,"n",NULL);
   context->addFunction("eps",EpsFunction,0,1,NULL);
   context->addFunction("feps",FepsFunction,0,1,NULL);
   context->addFunction("repmat",RepMatFunction,3,1,"x","rows","cols",NULL);
+  context->addSpecialFunction("docli",DoCLIFunction,0,0,NULL);
   context->addFunction("tic",TicFunction,0,0,NULL);
   context->addFunction("toc",TocFunction,0,1,NULL);
   context->addFunction("xnrm2",XNrm2Function,1,1,"x",NULL);
@@ -201,9 +221,13 @@ void LoadCoreFunctions(Context* context) {
   context->addFunction("strstr",StrStrFunction,2,1,"x","y",NULL);
   context->addFunction("strrep_string",StrRepStringFunction,3,1,"source","pattern","replace",NULL);
   context->addFunction("conv2",Conv2Function,4,1,"A","B","C","keep",NULL);
-  context->addFunction("inv",InvFunction,1,1,"A",NULL);
+  context->addFunction("permute",PermuteFunction,2,1,"A","permutation",NULL);
+  context->addSpecialFunction("inv",InvFunction,1,1,"A",NULL);
   context->addFunction("rcond",RcondFunction,1,1,"A",NULL);
   context->addFunction("end",EndFunction,3,1,"x","n","dims",NULL);
+  context->addFunction("xmlread",XMLReadFunction,1,1,"filename",NULL);
+  context->addFunction("htmlread",HTMLReadFunction,1,1,"filename",NULL);
+  context->addFunction("urlwrite",URLWriteFunction,3,1,"url","filename","timeout",NULL);
   context->addFunction("p_end",EndFunction,3,1,"x","n","dims",NULL);
   context->addSpecialFunction("matload",MatLoadFunction,-1,0,NULL);
   context->addSpecialFunction("matsave",MatSaveFunction,-1,0,NULL);
