@@ -170,7 +170,7 @@ Array ClassAux(Array s, std::string classname, rvstring parentNames,
   for (int j=0;j<parents.size();j++) 
     for (int i=0;i<arrayLength;i++) {
       Array ndx(Array::int32Constructor(i+1));
-      dp[i*newFieldCount+oldFieldCount+j] = parents[j].getVectorSubset(ndx);
+      dp[i*newFieldCount+oldFieldCount+j] = parents[j].getVectorSubset(ndx,eval);
     }
   // return a new object with the specified properties
   Array retval(FM_STRUCT_ARRAY,s.dimensions(),dp,false,newfields);
@@ -803,7 +803,7 @@ ArrayVector ClassFunction(int nargout, const ArrayVector& arg,
   }
   Array sval(arg[0]);
   Array classname(arg[1]);
-  return singleArrayVector(ClassAux(sval,classname.getContentsAsCString(),
+  return singleArrayVector(ClassAux(sval,classname.getContentsAsString(),
 				    parentNames,parents,eval));
 }
 
@@ -813,7 +813,7 @@ void LoadClassFunction(Context* context) {
   sfdef->argCount = -1;
   sfdef->name = "class";
   sfdef->fptr = ClassFunction;
-  context->insertFunctionGlobally(sfdef,false);
+  context->insertFunction(sfdef,false);
 }
 
 std::vector<int> MarkUserClasses(ArrayVector t) {
@@ -855,7 +855,7 @@ Array ClassMatrixConstructor(ArrayMatrix m, Interpreter* eval) {
 						  val,"horzcat");
       // scan through the list of user defined classes - look
       // for one that has "horzcat" overloaded
-      val->updateCode();
+      val->updateCode(eval);
       ArrayVector p;
       p = val->evaluateFunction(eval,m[i],1);
       if (!p.empty())
@@ -886,7 +886,7 @@ Array ClassMatrixConstructor(ArrayMatrix m, Interpreter* eval) {
     FuncPtr val;
     bool vertcat_overload = ClassSearchOverload(eval,rows,userset,
 						val,"vertcat");
-    val->updateCode();
+    val->updateCode(eval);
     ArrayVector p;
     p = val->evaluateFunction(eval,rows,1);
     if (!p.empty())
@@ -902,7 +902,7 @@ Array ClassUnaryOperator(Array a, std::string funcname,
   FuncPtr val;
   ArrayVector m, n;
   if (eval->getContext()->lookupFunction(ClassMangleName(a.className().back(),funcname),val)) {
-    val->updateCode();
+    val->updateCode(eval);
     m.push_back(a);
     n = val->evaluateFunction(eval,m,1);
     if (!n.empty())
@@ -944,7 +944,7 @@ void printClassNames(Array a) {
 // TODO - add "inferiorto", etc and class precedence
 
 Array ClassBiOp(Array a, Array b, FuncPtr val, Interpreter *eval) {
-  val->updateCode();
+  val->updateCode(eval);
   ArrayVector m, n;
   m.push_back(a); m.push_back(b);
   n = val->evaluateFunction(eval,m,1);
@@ -955,7 +955,7 @@ Array ClassBiOp(Array a, Array b, FuncPtr val, Interpreter *eval) {
 }
 
 Array ClassTriOp(Array a, Array b, Array c, FuncPtr val, Interpreter *eval) {
-  val->updateCode();
+  val->updateCode(eval);
   ArrayVector m, n;
   m.push_back(a); m.push_back(b); m.push_back(c);
   n = val->evaluateFunction(eval,m,1);
@@ -1060,7 +1060,7 @@ ArrayVector ClassSubsrefCall(Interpreter* eval, const tree &t, Array r, FuncPtr
   ArrayVector p;
   p.push_back(r);
   p.push_back(IndexExpressionToStruct(eval,t, r));
-  val->updateCode();
+  val->updateCode(eval);
   ArrayVector n = val->evaluateFunction(eval,p,1);
   return n;
 }
@@ -1098,10 +1098,10 @@ ArrayVector ClassRHSExpression(Array r, const tree &t, Interpreter* eval) {
      if (m.size() == 0) 
 	throw Exception("Expected indexing expression!");
      else if (m.size() == 1) {
-	q = r.getVectorSubset(m[0]);
-	r = q;
+       q = r.getVectorSubset(m[0],eval);
+       r = q;
      } else {
-	q = r.getNDimSubset(m);
+       q = r.getNDimSubset(m,eval);
 	r = q;
      }
    }
@@ -1115,9 +1115,9 @@ ArrayVector ClassRHSExpression(Array r, const tree &t, Interpreter* eval) {
      if (m.size() == 0) 
 	throw Exception("Expected indexing expression!");
      else if (m.size() == 1)
-	rv = r.getVectorContentsAsList(m[0]);
+	rv = r.getVectorContentsAsList(m[0],eval);
      else
-	rv = r.getNDimContentsAsList(m);
+	rv = r.getNDimContentsAsList(m,eval);
      if (rv.size() == 1) {
 	r = rv[0];
 	rv = ArrayVector();
@@ -1140,10 +1140,10 @@ ArrayVector ClassRHSExpression(Array r, const tree &t, Interpreter* eval) {
      }
    }
    if (t.child(index).is(TOK_DYN)) {
-     char *field;
+     string field;
      try {
 	Array fname(eval->expression(t.child(index).first()));
-	field = fname.getContentsAsCString();
+	field = fname.getContentsAsString();
      } catch (Exception &e) {
 	throw Exception("dynamic field reference to structure requires a string argument");
      }
@@ -1159,7 +1159,7 @@ ArrayVector ClassRHSExpression(Array r, const tree &t, Interpreter* eval) {
  return rv;
 }
 
-void ClassAssignExpression(Array *dst, const tree &t, const Array& value, Interpreter* eval) {
+void ClassAssignExpression(ArrayReference dst, const tree &t, const Array& value, Interpreter* eval) {
   FuncPtr val;
   if (!ClassResolveFunction(eval,*dst,"subsasgn",val))
     throw Exception("The method 'subsasgn' is not defined for objects of class " + 
@@ -1168,7 +1168,7 @@ void ClassAssignExpression(Array *dst, const tree &t, const Array& value, Interp
   p.push_back(*dst);
   p.push_back(IndexExpressionToStruct(eval,t, *dst));
   p.push_back(value);
-  val->updateCode();
+  val->updateCode(eval);
   bool overload(eval->getStopOverload());
   eval->setStopOverload(true);
   ArrayVector n = val->evaluateFunction(eval,p,1);
