@@ -33,8 +33,6 @@
 #include <QWaitCondition>
 #include <QThread>
 
-extern "C" char* lasterr;
-
 using namespace std;
 
 class InterpreterContinueException : public exception {};
@@ -42,6 +40,7 @@ class InterpreterBreakException : public exception {};
 class InterpreterReturnException : public exception {};
 class InterpreterRetallException : public exception {};
 class InterpreterQuitException : public exception {};
+class InterpreterKillException : public exception {};
 
 class stackentry {
 public:
@@ -59,11 +58,12 @@ public:
   ~stackentry();
 };
 
-typedef Array (*BinaryFunc)(Array, Array);
-typedef Array (*UnaryFunc)(Array);
-
+class Interpreter;
 class UserClass;
 
+typedef Array (*BinaryFunc)(Array, Array, Interpreter*);
+typedef Array (*UnaryFunc)(Array, Interpreter*);
+
 /**
  * This is the class that implements the interpreter - it generally
  * operates on abstract syntax trees (ASTs).
@@ -78,7 +78,7 @@ class Interpreter : public QThread {
   /**
    * Members related to "end" references.
    */
-  Array *endRef;
+  ArrayReference endRef;
   int endTotal;
   int endCount;
 
@@ -198,7 +198,55 @@ class Interpreter : public QThread {
    * This flag controls the greeting
    */
   bool m_skipflag;
-
+  /**
+   * Our thread ID
+   */
+  int m_threadID;
+  /**
+   * The thread function we are executing
+   */
+  FunctionDef *m_threadFunc;
+  /**
+   * The arguments to the thread function we are executing
+   */
+  ArrayVector m_threadFuncArgs;
+  /**
+   * The number of return arguments expected
+   */
+  int m_threadNargout;
+  /**
+   * The return value of the thread function
+   */
+  ArrayVector m_threadFuncRets;
+  /**
+   * The error state of the thread function (true if an exception
+   * occured).
+   */
+  bool m_threadErrorState;
+  /**
+   * Interrupt the current thread at the next opportunity
+   */
+  bool m_interrupt;
+   /**
+   * Kill the thread at the next opportunity
+   */
+  bool m_kill;
+  /**
+   * The current state of diary output
+   */
+  bool m_diaryState;
+  /**
+   * The filename for the diary
+   */
+  string m_diaryFilename;
+  /**
+   * The capture string
+   */
+  string m_capture;
+  /**
+   * The capture state
+   */
+  bool m_captureState;
   /******************************************
    *  Public Methods for the Interpreter    *
    ******************************************/
@@ -212,6 +260,59 @@ public:
    * Destruct the Interpreter object.
    */
   ~Interpreter();
+  /**
+   * Set the thread ID to the given number...
+   */
+  inline void setThreadID(int threadID) {m_threadID = threadID;}
+  /**
+   * Return the thread ID
+   */
+  inline int getThreadID() const {return m_threadID;}
+  /**
+   * Set the thread function and the arguments
+   */
+  inline void setThreadFunc(FunctionDef *threadFunc, 
+			    int nargout,
+			    ArrayVector threadFuncArgs) { 
+    m_threadFunc = threadFunc;  
+    m_threadFuncArgs = threadFuncArgs; 
+    m_threadNargout = nargout;
+    m_threadErrorState = false;
+  }
+  /**
+   * Manipulate the diary state
+   */
+  inline bool getDiaryState() {return m_diaryState;}
+  inline void setDiaryState(bool t) {m_diaryState = t;}
+  inline void setDiaryFilename(string name) {m_diaryFilename = name;}
+  void diaryMessage(string msg);
+  /**
+   * Manipulate the capture state
+   */
+  inline void clearCaptureString() {m_capture = "";}
+  inline void setCaptureState(bool t) {m_captureState = t;}
+  inline string getCaptureString() {return m_capture;}
+  /**
+   * Get the result of the thread function evaluation
+   */
+  inline ArrayVector getThreadFuncReturn() {return m_threadFuncRets;}
+  /**
+   * Get the error state - is true if the thread function throws
+   * an exception.
+   */
+  inline bool getLastErrorState() {return m_threadErrorState;}
+  /**
+   * Activate the interrupt for the thread - so that it stops.
+   */
+  inline void setInterrupt() {m_interrupt = true;}
+   /**
+   * Activate the kill for the thread - so that it dies.
+   */
+  inline void setKill() {m_kill = true;}
+  /**
+   * Run a command-line-interface interface from this thread.
+   */
+  void doCLI();
   /**
    * Queue a command for execution
    */
@@ -281,7 +382,8 @@ public:
    */
   static string getVersionString();
   /**
-   * Retrieve the number of errors that occured
+   * Retrieve the number of errors that occured.  The
+   * side effect is that the error count is set to zero.
    */
   int getErrorCount();
   /**
@@ -335,6 +437,10 @@ public:
    * Register a new user class.
    */
   void registerUserClass(string classname, UserClass cdata);
+  /**
+   * Clear the registered class table
+   */
+  void clearUserClasses();
   /**
    * Push a function name and detail onto the debug stack
    */
@@ -392,10 +498,14 @@ public:
    * Simplified interface for function lookup.
    */
   bool lookupFunction(string funcName, FuncPtr& val);
-  /**
+   /**
    * Prompt the user for input, and return the answer.
    */
   string getLine(string prompt);
+  /**
+   * Go to sleep for the specified number of milliseconds
+   */
+  void sleepMilliseconds(unsigned long msecs);
   /**
    * Executes a sequence of statements, trapping exceptions
    * as necessary.  The AST looks like
@@ -407,6 +517,12 @@ public:
    *
    */
   void block(const tree &t);
+  /**
+   * Start a command line interface.  Statements are retrieved
+   * from the console, and executed sequentially until a "return"
+   * statement is executed or the user presses 'CTRL-D'.
+   */
+  void evalCLI();
 
   bool isBPSet(QString fname, int lineNumber);
   bool isInstructionPointer(QString fname, int lineNumber);
@@ -431,7 +547,7 @@ signals:
   /**
    * Dispatch a graphics call
    */
-  void doGraphicsCall(FuncPtr, ArrayVector, int);
+  void doGraphicsCall(Interpreter*, FuncPtr, ArrayVector, int);
   /**
    * All done.
    */
@@ -448,6 +564,14 @@ signals:
    * Show the current active line
    */
   void ShowActiveLine();
+  /**
+   * Enable repainting
+   */
+  void EnableRepaint();
+  /**
+   * Disable repainting
+   */
+  void DisableRepaint();
 
   /******************************************
    *  Private Methods for the Interpreter   *
@@ -527,6 +651,8 @@ private:
    */
   Array expression(const tree &t);
 
+  ArrayVector handleReindexing(const tree &t, const ArrayVector &p);
+  
   /**
    * Evaluate the expression into a variable-array
    */
@@ -592,9 +718,9 @@ private:
    */
   ArrayVector rhsExpression(const tree &t, int lhsCount = 1);
 
-  void assign(Array *r, const tree &s, Array &data);
+  void assign(ArrayReference r, const tree &s, Array &data);
 
-  void multiassign(Array *r, const tree &s, ArrayVector& m);
+  void multiassign(ArrayReference r, const tree &s, ArrayVector& m);
 
   void deref(Array &r, const tree &s);
 
@@ -847,12 +973,6 @@ private:
    * line number and filename if necessary).
    */
   void statement(const tree &t);
-  /**
-   * Start a command line interface.  Statements are retrieved
-   * from the console, and executed sequentially until a "return"
-   * statement is executed or the user presses 'CTRL-D'.
-   */
-  void evalCLI();
   /**
    * Handles the logistics of shortcut evaluation
    */
@@ -866,6 +986,7 @@ private:
    * Mangle a function name to get the private version (if it exists)
    */
   string getPrivateMangledName(string fname);
+  string getLocalMangledName(string fname);
   /**
    * Convert variables into indexes, calls "subsindex" for user classes.
    */
@@ -907,6 +1028,5 @@ private:
 
 void sigInterrupt(int arg);
 string TrimFilename(string);
-char* TildeExpand(char* path);
-
+QString TildeExpand(string);
 #endif
