@@ -29,7 +29,7 @@ MINGW_ATLAS_FILE="atlas3.6.0_WinNT_P2.zip"
 ARPACK_FILE="arpack96.tar.Z"
 ARPACK_URL="http://www.caam.rice.edu/software/ARPACK/SRC"
 ARPACK="ARPACK"
-VERSION="3.1"
+VERSION="3.2"
 FREEMAT="FreeMat-$VERSION"
 FREEMAT_FILE="$FREEMAT.tar.gz"
 ZLIB_FILE="zlib-1.2.3.tar.gz"
@@ -373,6 +373,7 @@ SetupPCRE()
     SetupCommon
     DownloadAndUnpackTarBall $PCRE_FILE ftp://ftp.csx.cam.ac.uk/pub/software/programming/pcre $PCRE Root
     ConfigureMakeInstall $PCRE "--prefix=$PREFIX" . Root
+    rm -rf $BASE/Build/lib/lib*.dylib
 }
 
 SetupFFTW()
@@ -510,7 +511,7 @@ SetupRPM()
     mkdir -p $BASE/rpm/SRPMS
     cp $BASE/Root/$FREEMAT/tools/freemat.spec $BASE/rpm/SPECS/.
     cp $BASE/Files/$FREEMAT_FILE $BASE/rpm/SOURCES/.
-    rpmbuild -ba --define '_topdir $BASE/rpm' $BASE/rpm/SPECS/freemat.spec
+    rpmbuild -ba --define "_topdir $BASE/rpm" $BASE/rpm/SPECS/freemat.spec
 }
 
 SetupFreeMat()
@@ -805,6 +806,7 @@ SetupXMacPCRE()
     SetupXWinCommon
     DownloadAndUnpackTarBall $PCRE_FILE ftp://ftp.csx.cam.ac.uk/pub/software/programming/pcre $PCRE XRoot
     ConfigureMakeInstall $PCRE "--prefix=$PREFIX CC=powerpc-apple-darwin8-gcc-4.0.1" . XRoot
+    rm -rf $BASE/Cross/lib/lib*.dylib
 }
 
 SetupXMacSparse()
